<template>
  <gree-popup class="assht-popup" position="bottom" get-container="body" v-model="isShow" safe-area-inset-bottom @hide="onHide">
    <gree-radio-list :value="AssHt" :options="radioLists" @change="onClick"> </gree-radio-list>
  </gree-popup>
</template>

<script>
import { popup, RadioList } from 'gree-ui';
import { types } from '@/store/types';
import { mapState, mapMutations, mapGetters, mapActions } from 'vuex';

export default {
  name: 'AssHtPopup',
  components: {
    [popup.name]: popup,
    [RadioList.name]: RadioList
  },
  data() {
    return {
      isShow: false
    };
  },
  computed: {
    ...mapState('control', {
      AssHtPopup: state => state.popup.AssHtPopup,
      StHt: state => state.dataObject.StHt || 0,
      AssHt: state => state.dataObject.AssHt,
      Pow: state => state.dataObject.Pow
    }),
    ...mapGetters([
      'modTextKey',
      'modIdentifier',
      'modCurrentStatusName',
      'temSetVal',
      'temSetJson',
      'temMinVal',
      'temMaxVal',
      'spModCurrentStatusName',
      'spModIdentifier'
    ]),
    ...mapGetters('machine', ['statusMap']),
    radioLists() {
      return [
        {
          value: 2,
          text: '自动',
          brief: '根据环境自动开启或关闭辅热'
        },
        {
          value: 1,
          text: '常开',
          brief: ''
        },
        {
          value: 0,
          text: '关闭',
          brief: ''
        }
      ];
    }
  },
  watch: {
    AssHtPopup(val) {
      this.isShow = val;
    },
    Pow(val) {
      if (!val) {
        this.isShow = false;
      }
    }
  },
  methods: {
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP',
      setDataObject: 'SET_DATA_OBJECT'
    }),
    ...mapActions({
      sendData: types.SEND_DATA,
      sendCtrl: types.SEND_CTRL,
      stateMatchineInterFace: 'STATE_MACHINE_INTERFACE'
    }),
    onClick(option) {
      this.sendData({
        AssHt: option.value,
        StHt: 0
      });
    },
    onHide() {
      this.SetPopup({ AssHtPopup: false });
    }
  }
};
</script>

<style lang="scss">
.assht-popup {
  width: 100%;
  color: #404657;
  .gree-radio-list {
    .gree-radio-icon {
      .gree-icon.icon-font.checked {
        color: #ffac83;
      }
    }
  }
}
</style>
